==> quadkonsole-2.0.3.tar.bz2: quadkonsole-2.0.3/src/mousemovefilter.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Simon Perreault   *
 *   nomis80@nomis80.org   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef _MOUSEMOVEFILTER_H_
#define _MOUSEMOVEFILTER_H_

#include <qobject.h>

class MouseMoveFilter : public QObject
{
    Q_OBJECT
public:
    MouseMoveFilter( QObject* parent );

protected:
    bool eventFilter( QObject* o, QEvent* e );
};

#endif // _MOUSEMOVEFILTER_H_

==> quadkonsole4-0.4.4.tar.bz2: quadkonsole4-0.4.4/src/mousemovefilter.h <==
/***************************************************************************
 *   Copyright (C) 2005 by Simon Perreault                                 *
 *   nomis80@nomis80.org                                                   *
 *   Copyright (C) 2009 - 2011 by Karsten Borgwaldt                        *
 *   kb@kb.ccchl.de                                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef MOUSEMOVEFILTER_H
#define MOUSEMOVEFILTER_H

#include <QtCore/QObject>

class MouseMoveFilter : public QObject
{
	Q_OBJECT
	public:
		MouseMoveFilter(QObject* parent=0);

	protected:
		bool eventFilter(QObject* o, QEvent* e);
};

#endif // MOUSEMOVEFILTER_H
